@@ -32,7 +32,7 @@ class Builder:
 
     def make_build_dir(self):
         dest_dir = self.config.dest_dir
-        print(f'- Prepare a build dir: {dest_dir}')
+        print(f"- Prepare a build dir: {dest_dir}")
         fs.rm_dir(dest_dir)
         fs.make_dir(dest_dir)
 
@@ -40,17 +40,17 @@ class Builder:
         assets_dir = self.config.assets_dir
         assets_dest_dir = self.blog.config.assets_dest_dir
         fs.make_dir(assets_dest_dir)
-        print(f'- Copy assets from {assets_dir} to {assets_dest_dir}')
+        print(f"- Copy assets from {assets_dir} to {assets_dest_dir}")
         fs.copy_dir(assets_dir, assets_dest_dir)
 
     def render_all(self):
         for entity in self.vault.page_types:
-            print(f'# Render {entity}:')
+            print(f"# Render {entity}:")
             tic = time.perf_counter()
 
             pages = getattr(self.vault, entity)
             for page in pages:
-                print(f'- {page.data.title}')
+                print(f"- {page.data.title}")
                 if page.data.is_private:
                     print(
                         f"- [SKIP]: '{page.data.title}' is private, add `published: True` attribute to the frontmetter to publish it"
@@ -62,26 +62,26 @@ class Builder:
 
             toc = time.perf_counter()
 
-            print('')
+            print("")
             print(
-                f'{len(pages)} {entity} have been rendered in {toc-tic:0.4f} seconds\n'
+                f"{len(pages)} {entity} have been rendered in {toc-tic:0.4f} seconds\n"
             )
 
     def render(self, page):
         dest_dir = self.config.dest_dir
         dest = os.path.join(dest_dir, page.data.slug)
-        ctx = self.create_context({'self': page.data})
+        ctx = self.create_context({"self": page.data})
         html = page.render(ctx)
         layout = self.get_layout(page)
 
         if layout is not None:
-            ctx.update({'content': html})
+            ctx.update({"content": html})
             html = layout.render(ctx)
 
         fs.write_file(dest, html)
 
     def get_layout(self, node):
-        layout_name = node.data.meta.get('layout') or 'main'
+        layout_name = node.data.meta.get("layout") or "main"
         return self.blog.layouts[layout_name]
 
     def process_assets(self, page):
@@ -91,7 +91,7 @@ class Builder:
             if not issubclass(type(content_data), ContentData):
                 continue
 
-            if content_data.ext == '.md':
+            if content_data.ext == ".md":
                 continue
 
             if validators.url(content_data.filename):
@@ -100,15 +100,15 @@ class Builder:
             try:
                 public_dir = self.config.public_dir
                 assets_dest_dir = self.config.assets_dest_dir
-                dest_filename = f'{content_data.id}{content_data.ext}'
+                dest_filename = f"{content_data.id}{content_data.ext}"
 
                 frm = content_data.filename
-                to = f'{assets_dest_dir}/{dest_filename}'
+                to = f"{assets_dest_dir}/{dest_filename}"
                 url = os.path.join(public_dir, dest_filename)
 
                 fs.copyfile(frm, to)
                 content_data.filename = url
-                print(f'  - [COPY ASSET]: {frm} to {to}')
+                print(f"  - [COPY ASSET]: {frm} to {to}")
 
             except:
                 # FIXME: Should skip abs paths and urls
@@ -116,15 +116,15 @@ class Builder:
 
     def preprocess_content(self, page):
         for processor in self.preprocessors:
-            if hasattr(processor, 'process_page') and callable(
-                getattr(processor, 'process_page')
+            if hasattr(processor, "process_page") and callable(
+                getattr(processor, "process_page")
             ):
                 processor.process_page(page)
 
         for entity in page.data.entities:
             for processor in self.preprocessors:
-                if hasattr(processor, 'process_entity') and callable(
-                    getattr(processor, 'process_entity')
+                if hasattr(processor, "process_entity") and callable(
+                    getattr(processor, "process_entity")
                 ):
                     processor.process_entity(entity)
 
@@ -133,10 +133,10 @@ class Builder:
             local_ctx = {}
 
         global_ctx = {
-            'config': self.config,
-            'layouts': self.blog.layouts,
-            'pages': self.vault.pages,
-            'posts': self.vault.posts,
+            "config": self.config,
+            "layouts": self.blog.layouts,
+            "pages": self.vault.pages,
+            "posts": self.vault.posts,
         }
         global_ctx.update(local_ctx)
         return global_ctx
