@@ -10,5 +10,5 @@ class Image:
 
     def render(self, data):
         content = data.content
-        rendered_image = f'![{self.data.title}]({self.data.filename})'
+        rendered_image = f"![{self.data.title}]({self.data.filename})"
         return content.replace(self.data.placeholder, rendered_image)
