@@ -3,7 +3,7 @@ from src.dataclasses.content_data import ContentData
 from src.dataclasses.asset_data import AssetData
 from src.entities.image import Image
 
-INLINE_IMG_RE = r'(\!\[(.*?)\]\((.*?)\))'
+INLINE_IMG_RE = r"(\!\[(.*?)\]\((.*?)\))"
 
 
 class InlineImage(Image):
@@ -12,7 +12,7 @@ class InlineImage(Image):
         if not isinstance(entity.data, ContentData):
             return []
 
-        if entity.data.ext is '.md':
+        if entity.data.ext is ".md":
             return []
 
         imgs = []
